@@ -4,10 +4,10 @@
 #define _H_demo_
 
 /*
-   $Id: demo.h,v 1.3 2003-11-30 14:21:29 frank Exp $
+   $Id: demo.h 30 2003-11-30 14:21:29Z frank $
 
-   $Log: demo.h,v $
-   Revision 1.3  2003-11-30 14:21:29  frank
+   $Log$
+   Revision 1.3  2003/11/30 14:21:29  frank
    Adding facilities to reuse the Reporter: reinit() re-initializes the reporter
    but note that reset() must still be used. See demo/demo.cc for an example
 
