@@ -7,26 +7,27 @@ void Scanner::copy(std::istream &src, string const &fname)
     ofstream currentReport(fname.c_str());
 
     if (!currentReport)
-        d_reporter.exit() << "Can't open `" << fname << "' to write" << endl;
+        d_reporter.error() << "Can't open `" << fname << "' to write" << endl;
+
+    imsg << "Scanner::copy(): about to read child input" << endl;
 
     string s;
     off_t length = 0;
-
-    Util::debug() << "Scanner::copy(): about to read child input " << endl;
-
     while (getline(src, s))
     {
         if (!checkSize(fname, length += s.length() + 1))
             return;
 
-        Util::debug() << "copy SAW: `" << s << "'" << endl;
+        imsg << "copy SAW: `" << s << '\'' << endl;
 
         if (s.find(d_sentinel) == 0)
         {
-            Util::debug() << "GOT Sentinel" << endl;
+            imsg << "GOT Sentinel" << endl;
             break;
         }
-        currentReport << s << endl;
+
+        if (not (this->*d_skip)(s))
+            currentReport << s << '\n';
     }
     testExitValue(s);
 }
