@@ -2,15 +2,15 @@
 
 void Scanner::nextCommand(ostream &out, string const &command)
 {
-    Util::debug() << "Scanner::nextCommand(): inserting\n" << command << \
-            "\nand: echo " << d_sentinel << " $?" << endl;
+    imsg << "Scanner::nextCommand(): inserting\n" << command << "\n"
+                "and: echo " << d_sentinel << " $?" << endl;
 
                         // run the command, then 
                         // echo the sentinel and returnvalue
-    out << command << endl <<
+    out << command << "\n" 
            "/bin/echo \"" << d_sentinel << " $?\""  << endl;
 
     if (!out)
-        d_reporter.exit() << 
+        d_reporter.error() << 
             "Inserting command `" << s_firstWord[0] << "' failed." << endl;
 }
