@@ -12,9 +12,9 @@ is used.
 Scanner::Scanner(ConfigSorter &sorter, Reporter &reporter)
 :
     d_sorter(sorter),
-    d_reporter(reporter),                       // ostream
-    d_firstWord(*new Pattern("(\\S+)(\\s+(.*))?")),// firstword ([1]) and 
-                                                // the rest ([3]) of a text
+    d_reporter(reporter),                           // ostream
+    d_firstWord(*new Pattern("(\\S+)(\\s+(.*))?")), // firstword ([1]) and the
+                                                    // rest ([3]) of a text
     d_sshFork
     (
         Process::CIN | Process::COUT | Process::IGNORE_CERR,
@@ -35,7 +35,15 @@ Scanner::Scanner(ConfigSorter &sorter, Reporter &reporter)
 {
     setSentinel();
 
-    if (Arg::instance().option(&d_maxSizeStr, "max-size"))
+    Arg &arg = Arg::instance();
+
+    string name;
+    if (arg.option(&name, 's'))         // skip files
+        setSkip(name);
+    else                                // or skip none
+        d_skip = &Scanner::dontSkip;
+
+    if (arg.option(&d_maxSizeStr, "max-size"))
     {
         d_maxSize = A2x(d_maxSizeStr);
         switch(d_maxSizeStr.find_first_not_of("0123456789"))
@@ -62,7 +70,7 @@ Scanner::Scanner(ConfigSorter &sorter, Reporter &reporter)
                 break;
 
             default:
-                d_reporter.exit() << 
+                d_reporter.error() << 
                     "Error in --max-size option specification: " << 
                      d_maxSizeStr << endl;
         }
