@@ -8,11 +8,11 @@ void Scanner::waitForSentinel(istream &extractor)
 
     while (getline(extractor, s))
     {
-        Util::debug() << "Read line `" << s << "'" << endl;
+        imsg << "Read line `" << s << '\'' << endl;
 
         if (s.find(d_sentinel) == 0)
         {
-            Util::debug() << "GOT Sentinel" << endl;
+            imsg << "GOT Sentinel" << endl;
             break;
         }
     }
